measuretools.make_measures_with_full_measure_spacer_skips
=========================================================

.. autofunction:: abjad.tools.measuretools.make_measures_with_full_measure_spacer_skips.make_measures_with_full_measure_spacer_skips
